==> 0.3.24+6.tar.gz: lib/widgets/story/story_button.dart <==
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/share_story.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

//הכפתור העגול עם הפלוס- להעלאת סטורי
class StoryButtonPage extends StatefulWidget {
  final loc;
  final UserModel? currentUser;
  final Function onTap;

  const StoryButtonPage({
    required this.loc,
    required this.currentUser,
    required this.onTap,
  });

  @override
  _StoryButtonPageState createState() => _StoryButtonPageState();
}

class _StoryButtonPageState extends State<StoryButtonPage> {
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () async {
        var res = await Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => ShareStoryPage(
              currentUser: widget.currentUser,
              loc: widget.loc,
            ),
          ),
        );
        widget.onTap();
      },
      child: Container(
        padding: const EdgeInsets.all(4.0),
        margin: const EdgeInsets.all(4.0),
        height: 60,
        width: 60,
        decoration: new BoxDecoration(
          shape: BoxShape.circle,
          border: new Border.all(
            color: Colors.grey,
            width: 0.6,
          ),
        ),
        child: Container(
            decoration: new BoxDecoration(
              shape: BoxShape.circle,
              color: appDisabledButtonColor,
            ),
            child: Center(
              child: Icon(
                Icons.add_outlined,
                color: appDarkBlueColor,
                size: ScreenUtil().setHeight(30.0),
              ),
            ),
          
        ),
      ),
    );
  }
}

==> 0.3.25+7.tar.gz: lib/widgets/story/story_button.dart <==
import 'package:feed_plugin/models/user_model.dart';
import 'package:feed_plugin/pages/share_story.dart';
import 'package:feed_plugin/utilities/colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

//הכפתור העגול עם הפלוס- להעלאת סטורי
class StoryButtonPage extends StatefulWidget {
  final loc;
  final UserModel currentUser;
  final Function onTap;

  const StoryButtonPage({
    required this.loc,
    required this.currentUser,
    required this.onTap,
  });

  @override
  _StoryButtonPageState createState() => _StoryButtonPageState();
}

class _StoryButtonPageState extends State<StoryButtonPage> {
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () async {
        var res = await Navigator.push(
          context,
          MaterialPageRoute(
            builder: (context) => ShareStoryPage(
              currentUser: widget.currentUser,
              loc: widget.loc,
            ),
          ),
        );
        widget.onTap();
      },
      child: Container(
        padding: const EdgeInsets.all(4.0),
        margin: const EdgeInsets.all(4.0),
        height: 60,
        width: 60,
        decoration: new BoxDecoration(
          shape: BoxShape.circle,
          border: new Border.all(
            color: Colors.grey,
            width: 0.6,
          ),
        ),
        child: Container(
            decoration: new BoxDecoration(
              shape: BoxShape.circle,
              color: appDisabledButtonColor,
            ),
            child: Center(
              child: Icon(
                Icons.add_outlined,
                color: appDarkBlueColor,
                size: ScreenUtil().setHeight(30.0),
              ),
            ),
          
        ),
      ),
    );
  }
}
